package Mailtrace::System::Logging;

# Includes
use strict;
use warnings;
use Sys::Syslog;

# Constructor
sub new {
	my ($invocant, $program_name, $facility) = @_;
	
	# Was the constructor called by an instance or an class?
	my $class = ref($invocant) || $invocant;
	
	# Instance is a hash reference
	my $self = {
		'debug' => 0,
		'callingProgram' => $program_name,
		'facilitiy' => $facility
	};
	
	# Make hashreference to an instance
	bless ($self, $class); 
	
	# Return the instance
    return $self
}

sub log_syslog {
	my ($self, $level, $msg) = @_;
	
	# Open syslog and close it after work
    openlog($self->{'callingProgram'}, "ndelay,pid", $self->{'facility'});
	
	# Split the string to get each line
   	for (split(/\n/,$msg)) {
   		syslog($level, $_);
   	}
   	
	closelog();
	
	return 1;
}

# Set debug object variable to one
sub activate_debug {
	my ($self) = @_;
	$self->{'debug'} = 1;
	return 1;
}

# Method for debugging, 1 => INFO and 0 => ERROR
sub debug {
	my ($self, $error_code, $message) = @_;
	
	# Only print messages if debugging is switched on
    if (($self->{'debug'} == 1) && ($error_code == 0)) {
    	$self->log_syslog('debug', "DEBUG-ERROR: ".$message);
    	
    } elsif (($self->{'debug'} == 1) && ($error_code == 1)) {
    	$self->log_syslog('debug', "DEBUG-INFO: ".$message);
    }
	
	return 1;
}

1;

__END__